package
Version:
v0.3.2
Opens a new window with list of versions in this module.
Published: Nov 14, 2022
License: MulanPSL-2.0
Opens a new window with license information.
Imports: 0
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type SubAElem struct {
IDList []string `json:"id_list,omitempty"`
Lang string `json:"lang,omitempty"`
}
type SubAReq struct {
List []*SubAElem `json:"list,omitempty"`
}
type SubARsp struct {
Modified []string `json:"modified,omitempty"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.