package
Version:
v0.3.2
Opens a new window with list of versions in this module.
Published: Nov 14, 2022
License: MulanPSL-2.0
Opens a new window with license information.
Imports: 2
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
const (
ProtoIDSubAReq = 30001
ProtoIDSubARsp = 30002
)
type SubAElem struct {
IDList []string `json:"id_list,omitempty" protobuf:"1"`
Lang string `json:"lang,omitempty" protobuf:"2"`
}
type SubAReq struct {
List []*SubAElem `json:"list,omitempty" protobuf:"11"`
}
type SubARsp struct {
Modified []string `json:"modified,omitempty" protobuf:"11"`
Reward []*super_schema.ItemElem `json:"reward,omitempty" protobuf:"12"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.