package
Version:
v0.3.2
Opens a new window with list of versions in this module.
Published: Nov 14, 2022
License: MulanPSL-2.0
Opens a new window with license information.
Imports: 0
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
const (
ProtoIDSubReq = 40001
ProtoIDSubRsp = 40002
)
type SubReq struct {
ParamA string `json:"paramA,omitempty" protobuf:"1"`
}
type SubRsp struct {
ReturnA string `json:"returnA,omitempty" protobuf:"1"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.